@@ -2,14 +2,13 @@ use strict;
 use warnings;
 
 package Message::String;
-our $VERSION = '0.1.7'; # VERSION
+our $VERSION = '0.1.8'; # VERSION
 # ABSTRACT: A pragma to declare and organise messaging.
 use Clone           ( 'clone' );
 use DateTime        ();
 use List::MoreUtils ( 'distinct' );
 use Scalar::Util    ( 'reftype' );
 use Sub::Util       ( 'set_subname' );
-use Syntax::Feature::Void;
 use Term::ReadKey;
 use namespace::clean;
 use overload ( fallback => 1, '""' => 'to_string' );
@@ -1020,7 +1019,7 @@ sub _new
 #   Import new messages into the caller's namespace.
 sub import
 {
-    my ( $package, my @args ) = @_;
+    my ( $package, @args ) = @_;
     if ( @args ) {
         my ( @tags, @messages, $export, $export_ok );
         my $caller = caller;
@@ -1099,9 +1098,6 @@ sub import
                     $export_ok = 1;
                     undef $export;
                 }
-                elsif ( $this_arg eq 'void' ) {
-                    Syntax::Feature::Void->import( 'void' );
-                }
                 else {
                     if ( @args ) {
                         push @messages, __PACKAGE__->_new( $this_arg, shift( @args ) );
@@ -1145,7 +1141,7 @@ Message::String - A pragma to declare and organise messaging.
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 SYNOPSIS
 
@@ -1336,8 +1332,6 @@ deductions:
 
 =item * That messages are simple text, or they may be parameterised.
 
-=item * That calling context matters, particularly B<void> context.
-
 =back
 
 You possibly have more questions. Certainly, there is more to the story 
@@ -1401,17 +1395,6 @@ B<Options>
 
 =over
 
-=item C<void>
-
-Makes the C<void> operator available for use in the calling module. Since
-the active aspects of message handling are only triggered in void context, 
-it provides an extra level of comfort to developers who are unsure whether
-a statement will be executed in the correct context.
-
-The C<void> operator is B<essential> if testing with messages.
-
-The C<void> operator is provided by C<L<Syntax::Feature::Void>>. 
-
 =item C<EXPORT>
 
 Ensures that the caller's C<@EXPORT> list includes the names of messages
@@ -2101,10 +2084,6 @@ Standing as we all do from time to time on the shoulders of giants:
 
 For L<DateTime>
 
-=item Eric Brine
-
-For L<Syntax::Feature::Void>.
-
 =item Graham BarrI<, et al.>
 
 For L<Scalar::Util> and L<Sub::Util>
